@@ -22,13 +22,14 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.EnumMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.TreeMap;
+import java.util.stream.Collectors;
 
 import org.apache.commons.codec.language.bm.Languages.LanguageSet;
 import org.apache.commons.codec.language.bm.Rule.Phoneme;
@@ -40,15 +41,17 @@ import org.apache.commons.codec.language.bm.Rule.Phoneme;
  * into account the likely source language. Next, this phonetic representation is converted into a
  * pan-European 'average' representation, allowing comparison between different versions of essentially
  * the same word from different languages.
+ * </p>
  * <p>
  * This class is intentionally immutable and thread-safe.
  * If you wish to alter the settings for a PhoneticEngine, you
  * must make a new one with the updated settings.
+ * </p>
  * <p>
  * Ported from phoneticengine.php
+ * </p>
  *
  * @since 1.6
- * @version $Id$
  */
 public class PhoneticEngine {
 
@@ -84,14 +87,12 @@ public class PhoneticEngine {
         }
 
         /**
-         * Creates a new phoneme builder containing all phonemes in this one extended by <code>str</code>.
+         * Creates a new phoneme builder containing all phonemes in this one extended by {@code str}.
          *
          * @param str   the characters to append to the phonemes
          */
         public void append(final CharSequence str) {
-            for (final Rule.Phoneme ph : this.phonemes) {
-                ph.append(str);
-            }
+            phonemes.forEach(ph -> ph.append(str));
         }
 
         /**
@@ -99,6 +100,7 @@ public class PhoneticEngine {
          * <p>
          * This will lengthen phonemes that have compatible language sets to the expression, and drop those that are
          * incompatible.
+         * </p>
          *
          * @param phonemeExpr   the expression to apply
          * @param maxPhonemes   the maximum number of phonemes to build up
@@ -142,25 +144,16 @@ public class PhoneticEngine {
          * @return  the stringified phoneme set
          */
         public String makeString() {
-            final StringBuilder sb = new StringBuilder();
-
-            for (final Rule.Phoneme ph : this.phonemes) {
-                if (sb.length() > 0) {
-                    sb.append("|");
-                }
-                sb.append(ph.getPhonemeText());
-            }
-
-            return sb.toString();
+            return phonemes.stream().map(Rule.Phoneme::getPhonemeText).collect(Collectors.joining("|"));
         }
     }
 
     /**
      * A function closure capturing the application of a list of rules to an input sequence at a particular offset.
-     * After invocation, the values <code>i</code> and <code>found</code> are updated. <code>i</code> points to the
-     * index of the next char in <code>input</code> that must be processed next (the input up to that index having been
-     * processed already), and <code>found</code> indicates if a matching rule was found or not. In the case where a
-     * matching rule was found, <code>phonemeBuilder</code> is replaced with a new builder containing the phonemes
+     * After invocation, the values {@code i} and {@code found} are updated. {@code i} points to the
+     * index of the next char in {@code input} that must be processed next (the input up to that index having been
+     * processed already), and {@code found} indicates if a matching rule was found or not. In the case where a
+     * matching rule was found, {@code phonemeBuilder} is replaced with a new builder containing the phonemes
      * updated by the matching rule.
      *
      * Although this class is not thread-safe (it has mutable unprotected fields), it is not shared between threads
@@ -178,9 +171,7 @@ public class PhoneticEngine {
 
         public RulesApplication(final Map<String, List<Rule>> finalRules, final CharSequence input,
                                 final PhonemeBuilder phonemeBuilder, final int i, final int maxPhonemes) {
-            if (finalRules == null) {
-                throw new NullPointerException("The finalRules argument must not be null");
-            }
+            Objects.requireNonNull(finalRules, "finalRules");
             this.finalRules = finalRules;
             this.phonemeBuilder = phonemeBuilder;
             this.input = input;
@@ -199,9 +190,9 @@ public class PhoneticEngine {
         /**
          * Invokes the rules. Loops over the rules list, stopping at the first one that has a matching context
          * and pattern. Then applies this rule to the phoneme builder to produce updated phonemes. If there was no
-         * match, <code>i</code> is advanced one and the character is silently dropped from the phonetic spelling.
+         * match, {@code i} is advanced one and the character is silently dropped from the phonetic spelling.
          *
-         * @return <code>this</code>
+         * @return {@code this}
          */
         public RulesApplication invoke() {
             this.found = false;
@@ -232,6 +223,8 @@ public class PhoneticEngine {
         }
     }
 
+    private static final int DEFAULT_MAX_PHONEMES = 20;
+
     private static final Map<NameType, Set<String>> NAME_PREFIXES = new EnumMap<>(NameType.class);
 
     static {
@@ -250,25 +243,15 @@ public class PhoneticEngine {
 
     /**
      * Joins some strings with an internal separator.
+     *
      * @param strings   Strings to join
      * @param sep       String to separate them with
-     * @return a single String consisting of each element of <code>strings</code> interleaved by <code>sep</code>
+     * @return a single String consisting of each element of {@code strings} interleaved by {@code sep}
      */
-    private static String join(final Iterable<String> strings, final String sep) {
-        final StringBuilder sb = new StringBuilder();
-        final Iterator<String> si = strings.iterator();
-        if (si.hasNext()) {
-            sb.append(si.next());
-        }
-        while (si.hasNext()) {
-            sb.append(sep).append(si.next());
-        }
-
-        return sb.toString();
+    private static String join(final List<String> strings, final String sep) {
+        return strings.stream().collect(Collectors.joining(sep));
     }
 
-    private static final int DEFAULT_MAX_PHONEMES = 20;
-
     private final Lang lang;
 
     private final NameType nameType;
@@ -327,24 +310,20 @@ public class PhoneticEngine {
      * @return the resulting phonemes
      */
     private PhonemeBuilder applyFinalRules(final PhonemeBuilder phonemeBuilder,
-                                           final Map<String, List<Rule>> finalRules) {
-        if (finalRules == null) {
-            throw new NullPointerException("finalRules can not be null");
-        }
+            final Map<String, List<Rule>> finalRules) {
+        Objects.requireNonNull(finalRules, "finalRules");
         if (finalRules.isEmpty()) {
             return phonemeBuilder;
         }
 
-        final Map<Rule.Phoneme, Rule.Phoneme> phonemes =
-            new TreeMap<>(Rule.Phoneme.COMPARATOR);
+        final Map<Rule.Phoneme, Rule.Phoneme> phonemes = new TreeMap<>(Rule.Phoneme.COMPARATOR);
 
-        for (final Rule.Phoneme phoneme : phonemeBuilder.getPhonemes()) {
+        phonemeBuilder.getPhonemes().forEach(phoneme -> {
             PhonemeBuilder subBuilder = PhonemeBuilder.empty(phoneme.getLanguages());
             final String phonemeText = phoneme.getPhonemeText().toString();
 
             for (int i = 0; i < phonemeText.length();) {
-                final RulesApplication rulesApplication =
-                        new RulesApplication(finalRules, phonemeText, subBuilder, i, maxPhonemes).invoke();
+                final RulesApplication rulesApplication = new RulesApplication(finalRules, phonemeText, subBuilder, i, maxPhonemes).invoke();
                 final boolean found = rulesApplication.isFound();
                 subBuilder = rulesApplication.getPhonemeBuilder();
 
@@ -359,7 +338,7 @@ public class PhoneticEngine {
             // the phonemes map orders the phonemes only based on their text, but ignores the language set
             // when adding new phonemes, check for equal phonemes and merge their language set, otherwise
             // phonemes with the same text but different language set get lost
-            for (final Rule.Phoneme newPhoneme : subBuilder.getPhonemes()) {
+            subBuilder.getPhonemes().forEach(newPhoneme -> {
                 if (phonemes.containsKey(newPhoneme)) {
                     final Rule.Phoneme oldPhoneme = phonemes.remove(newPhoneme);
                     final Rule.Phoneme mergedPhoneme = oldPhoneme.mergeWithLanguage(newPhoneme.getLanguages());
@@ -367,8 +346,8 @@ public class PhoneticEngine {
                 } else {
                     phonemes.put(newPhoneme, newPhoneme);
                 }
-            }
-        }
+            });
+        });
 
         return new PhonemeBuilder(phonemes.keySet());
     }
@@ -407,7 +386,7 @@ public class PhoneticEngine {
         input = input.toLowerCase(Locale.ENGLISH).replace('-', ' ').trim();
 
         if (this.nameType == NameType.GENERIC) {
-            if (input.length() >= 2 && input.substring(0, 2).equals("d'")) { // check for d'
+            if (input.startsWith("d'")) { // check for d'
                 final String remainder = input.substring(2);
                 final String combined = "d" + remainder;
                 return "(" + encode(remainder) + ")-(" + encode(combined) + ")";
@@ -429,11 +408,10 @@ public class PhoneticEngine {
         // special-case handling of word prefixes based upon the name type
         switch (this.nameType) {
         case SEPHARDIC:
-            for (final String aWord : words) {
-                final String[] parts = aWord.split("'");
-                final String lastPart = parts[parts.length - 1];
-                words2.add(lastPart);
-            }
+            words.forEach(aWord -> {
+                final String[] parts = aWord.split("'", -1);
+                words2.add(parts[parts.length - 1]);
+            });
             words2.removeAll(NAME_PREFIXES.get(this.nameType));
             break;
         case ASHKENAZI:
@@ -453,12 +431,10 @@ public class PhoneticEngine {
         } else if (words2.size() == 1) {
             // not a multi-word name
             input = words.iterator().next();
-        } else {
+        } else if (!words2.isEmpty()) {
             // encode each word in a multi-word name separately (normally used for approx matches)
             final StringBuilder result = new StringBuilder();
-            for (final String word : words2) {
-                result.append("-").append(encode(word));
-            }
+            words2.forEach(word -> result.append("-").append(encode(word)));
             // return the result without the leading "-"
             return result.substring(1);
         }
@@ -490,6 +466,16 @@ public class PhoneticEngine {
         return this.lang;
     }
 
+    /**
+     * Gets the maximum number of phonemes the engine will calculate for a given input.
+     *
+     * @return the maximum number of phonemes
+     * @since 1.7
+     */
+    public int getMaxPhonemes() {
+        return this.maxPhonemes;
+    }
+
     /**
      * Gets the NameType being used.
      *
@@ -516,14 +502,4 @@ public class PhoneticEngine {
     public boolean isConcat() {
         return this.concat;
     }
-
-    /**
-     * Gets the maximum number of phonemes the engine will calculate for a given input.
-     *
-     * @return the maximum number of phonemes
-     * @since 1.7
-     */
-    public int getMaxPhonemes() {
-        return this.maxPhonemes;
-    }
 }
