@@ -17,19 +17,19 @@
 
 package org.apache.commons.codec.binary;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.util.Arrays;
 
-import org.junit.Test;
+import org.apache.commons.codec.CodecPolicy;
+import org.junit.jupiter.api.Test;
 
 public class Base32InputStreamTest {
 
@@ -42,40 +42,30 @@ public class Base32InputStreamTest {
     private static final String STRING_FIXTURE = "Hello World";
 
     /**
-     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
+     * Tests skipping past the end of a stream.
+     *
+     * @throws Throwable
+     *             for some failure scenarios.
      */
     @Test
-    public void testCodec130() throws IOException {
-        ByteArrayOutputStream bos = new ByteArrayOutputStream();
-        Base32OutputStream base32os = new Base32OutputStream(bos);
-
-        base32os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
-        base32os.close();
-
-        ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
-        Base32InputStream ins = new Base32InputStream(bis);
-
-        // we skip the first character read from the reader
-        ins.skip(1);
-        byte[] decodedBytes = Base32TestData.streamToBytes(ins, new byte[64]);
-        String str = StringUtils.newStringUtf8(decodedBytes);
-
-        assertEquals(STRING_FIXTURE.substring(1), str);
+    public void testAvailable() throws Throwable {
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            assertEquals(1, b32stream.available());
+            assertEquals(3, b32stream.skip(10));
+            // End of stream reached
+            assertEquals(0, b32stream.available());
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+            assertEquals(0, b32stream.available());
+        }
     }
 
-    /**
-     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
-     */
-    @Test
-    public void testCodec105() throws IOException {
-        Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null);
-        try {
-            for (int i = 0; i < 5; i++) {
-                in.read();
-            }
-        } finally {
-            in.close();
-        }
+    private void testBase32EmptyInputStream(final int chuckSize) throws Exception {
+        final byte[] emptyEncoded = {};
+        final byte[] emptyDecoded = {};
+        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
+        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
     }
 
     // /**
@@ -144,25 +134,6 @@ public class Base32InputStreamTest {
     // );
     // }
 
-    /**
-     * Tests skipping past the end of a stream.
-     *
-     * @throws Throwable
-     */
-    @Test
-    public void testAvailable() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        assertEquals(1, b32stream.available());
-        assertEquals(3, b32stream.skip(10));
-        // End of stream reached
-        assertEquals(0, b32stream.available());
-        assertEquals(-1, b32stream.read());
-        assertEquals(-1, b32stream.read());
-        assertEquals(0, b32stream.available());
-        b32stream.close();
-    }
-
     /**
      * Tests the Base32InputStream implementation against empty input.
      *
@@ -185,13 +156,6 @@ public class Base32InputStreamTest {
         testBase32EmptyInputStream(BaseNCodec.PEM_CHUNK_SIZE);
     }
 
-    private void testBase32EmptyInputStream(int chuckSize) throws Exception {
-        byte[] emptyEncoded = new byte[0];
-        byte[] emptyDecoded = new byte[0];
-        testByteByByte(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-        testByChunk(emptyEncoded, emptyDecoded, chuckSize, CRLF);
-    }
-
     /**
      * Tests the Base32InputStream implementation.
      *
@@ -221,10 +185,10 @@ public class Base32InputStreamTest {
         // decoded = Base32TestData.DECODED;
         // testByChunk(encoded, decoded, 0, LF);
 
-        // test random data of sizes 0 thru 150
-        BaseNCodec codec = new Base32();
+        // test random data of sizes 0 through 150
+        final BaseNCodec codec = new Base32();
         for (int i = 0; i <= 150; i++) {
-            byte[][] randomData = Base32TestData.randomData(codec, i);
+            final byte[][] randomData = BaseNTestData.randomData(codec, i);
             encoded = randomData[1];
             decoded = randomData[0];
             testByChunk(encoded, decoded, 0, LF);
@@ -255,10 +219,10 @@ public class Base32InputStreamTest {
         // decoded = Base32TestData.DECODED;
         // testByteByByte(encoded, decoded, 0, LF);
 
-        // test random data of sizes 0 thru 150
-        BaseNCodec codec = new Base32();
+        // test random data of sizes 0 through 150
+        final BaseNCodec codec = new Base32();
         for (int i = 0; i <= 150; i++) {
-            byte[][] randomData = Base32TestData.randomData(codec, i);
+            final byte[][] randomData = BaseNTestData.randomData(codec, i);
             encoded = randomData[1];
             decoded = randomData[0];
             testByteByByte(encoded, decoded, 0, LF);
@@ -278,42 +242,42 @@ public class Base32InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByChunk(byte[] encoded, byte[] decoded, int chunkSize, byte[] seperator) throws Exception {
+    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
-        
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
-        byte[] output = Base32TestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 encode", Arrays.equals(output, encoded));
+        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
+        byte[] output = BaseNTestData.streamToBytes(in);
 
-        // Now let's try decode.
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(encoded, output, "Streaming base32 encode");
+
+        // Now let's try to decode.
         in = new Base32InputStream(new ByteArrayInputStream(encoded));
-        output = Base32TestData.streamToBytes(in);
+        output = BaseNTestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 decode", Arrays.equals(output, decoded));
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base32 decode");
 
-        // I always wanted to do this! (wrap encoder with decoder etc etc).
+        // I always wanted to do this! (wrap encoder with decoder etc.).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base32InputStream(in, true, chunkSize, seperator);
+            in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
-        output = Base32TestData.streamToBytes(in);
+        output = BaseNTestData.streamToBytes(in);
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 wrap-wrap-wrap!", Arrays.equals(output, decoded));
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base32 wrap-wrap-wrap!");
         in.close();
     }
 
@@ -330,44 +294,44 @@ public class Base32InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByteByByte(byte[] encoded, byte[] decoded, int chunkSize, byte[] seperator) throws Exception {
+    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
+        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = new byte[encoded.length];
         for (int i = 0; i < output.length; i++) {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 encode", Arrays.equals(output, encoded));
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(encoded, output, "Streaming base32 encode");
 
         in.close();
 
-        // Now let's try decode.
+        // Now let's try to decode.
         in = new Base32InputStream(new ByteArrayInputStream(encoded));
         output = new byte[decoded.length];
         for (int i = 0; i < output.length; i++) {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 decode", Arrays.equals(output, decoded));
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base32 decode");
 
         in.close();
- 
-        // I always wanted to do this! (wrap encoder with decoder etc etc).
+
+        // I always wanted to do this! (wrap encoder with decoder etc.).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base32InputStream(in, true, chunkSize, seperator);
+            in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
         output = new byte[decoded.length];
@@ -375,41 +339,76 @@ public class Base32InputStreamTest {
             output[i] = (byte) in.read();
         }
 
-        assertEquals("EOF", -1, in.read());
-        assertEquals("Still EOF", -1, in.read());
-        assertTrue("Streaming base32 wrap-wrap-wrap!", Arrays.equals(output, decoded));
+        assertEquals(-1, in.read(), "EOF");
+        assertEquals(-1, in.read(), "Still EOF");
+        assertArrayEquals(decoded, output, "Streaming base32 wrap-wrap-wrap!");
+    }
+
+    /**
+     * Tests the bug reported in CODEC-105. Bad interactions with InputStream when reading one byte at a time.
+     */
+    @Test
+    public void testCodec105() throws IOException {
+        try (final Base32InputStream in = new Base32InputStream(new Codec105ErrorInputStream(), true, 0, null)) {
+            for (int i = 0; i < 5; i++) {
+                in.read();
+            }
+        }
+    }
+
+    /**
+     * Tests the problem reported in CODEC-130. Missing / wrong implementation of skip.
+     */
+    @Test
+    public void testCodec130() throws IOException {
+        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
+        try (final Base32OutputStream base32os = new Base32OutputStream(bos)) {
+            base32os.write(StringUtils.getBytesUtf8(STRING_FIXTURE));
+        }
+
+        final ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
+        final Base32InputStream ins = new Base32InputStream(bis);
+
+        // we skip the first character read from the reader
+        ins.skip(1);
+        final byte[] decodedBytes = BaseNTestData.streamToBytes(ins, new byte[64]);
+        final String str = StringUtils.newStringUtf8(decodedBytes);
+
+        assertEquals(STRING_FIXTURE.substring(1), str);
     }
 
     /**
      * Tests markSupported.
      *
      * @throws Exception
+     *             for some failure scenarios.
      */
     @Test
     public void testMarkSupported() throws Exception {
-        byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
-        ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 });
-        // Always returns false for now.
-        assertFalse("Base32InputStream.markSupported() is false", in.markSupported());
-        in.close();
+        final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
+        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
+        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+            // Always returns false for now.
+            assertFalse(in.markSupported(), "Base32InputStream.markSupported() is false");
+        }
     }
 
     /**
      * Tests read returning 0
      *
      * @throws Exception
+     *             for some failure scenarios.
      */
     @Test
     public void testRead0() throws Exception {
-        byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
-        byte[] buf = new byte[1024];
+        final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
+        final byte[] buf = new byte[1024];
         int bytesRead = 0;
-        ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 });
-        bytesRead = in.read(buf, 0, 0);
-        assertEquals("Base32InputStream.read(buf, 0, 0) returns 0", 0, bytesRead);
-        in.close();
+        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
+        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+            bytesRead = in.read(buf, 0, 0);
+            assertEquals(0, bytesRead, "Base32InputStream.read(buf, 0, 0) returns 0");
+        }
     }
 
     /**
@@ -420,138 +419,137 @@ public class Base32InputStreamTest {
      */
     @Test
     public void testReadNull() throws Exception {
-        byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
-        ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 });
-        try {
-            in.read(null, 0, 0);
-            fail("Base32InputStream.read(null, 0, 0) to throw a NullPointerException");
-        } catch (NullPointerException e) {
-            // Expected
+        final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
+        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
+        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] {0, 0, 0})) {
+            assertThrows(NullPointerException.class, () -> in.read(null, 0, 0));
         }
-        in.close();
     }
 
     /**
      * Tests read throwing IndexOutOfBoundsException
      *
      * @throws Exception
+     *             for some failure scenarios.
      */
     @Test
     public void testReadOutOfBounds() throws Exception {
-        byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
-        byte[] buf = new byte[1024];
-        ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
-        Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 });
-
-        try {
-            in.read(buf, -1, 0);
-            fail("Expected Base32InputStream.read(buf, -1, 0) to throw IndexOutOfBoundsException");
-        } catch (IndexOutOfBoundsException e) {
-            // Expected
+        final byte[] decoded = StringUtils.getBytesUtf8(Base32TestData.STRING_FIXTURE);
+        final byte[] buf = new byte[1024];
+        final ByteArrayInputStream bin = new ByteArrayInputStream(decoded);
+        try (final Base32InputStream in = new Base32InputStream(bin, true, 4, new byte[] { 0, 0, 0 })) {
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, -1, 0), "Base32InputStream.read(buf, -1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, 0, -1), "Base32InputStream.read(buf, 0, -1)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length + 1, 0), "Base32InputStream.read(buf, buf.length + 1, 0)");
+            assertThrows(IndexOutOfBoundsException.class, () -> in.read(buf, buf.length - 1, 2), "Base32InputStream.read(buf, buf.length - 1, 2)");
         }
-
-        try {
-            in.read(buf, 0, -1);
-            fail("Expected Base32InputStream.read(buf, 0, -1) to throw IndexOutOfBoundsException");
-        } catch (IndexOutOfBoundsException e) {
-            // Expected
-        }
-
-        try {
-            in.read(buf, buf.length + 1, 0);
-            fail("Base32InputStream.read(buf, buf.length + 1, 0) throws IndexOutOfBoundsException");
-        } catch (IndexOutOfBoundsException e) {
-            // Expected
-        }
-
-        try {
-            in.read(buf, buf.length - 1, 2);
-            fail("Base32InputStream.read(buf, buf.length - 1, 2) throws IndexOutOfBoundsException");
-        } catch (IndexOutOfBoundsException e) {
-            // Expected
-        }
-        in.close();
-    }
-
-    /**
-     * Tests skipping as a noop
-     *
-     * @throws Throwable
-     */
-    @Test
-    public void testSkipNone() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        byte[] actualBytes = new byte[6];
-        assertEquals(0, b32stream.skip(0));
-        b32stream.read(actualBytes, 0, actualBytes.length);
-        assertArrayEquals(actualBytes, new byte[] { 102, 111, 111, 0, 0, 0 });
-        // End of stream reached
-        assertEquals(-1, b32stream.read());
-        b32stream.close();
     }
 
     /**
      * Tests skipping number of characters larger than the internal buffer.
      *
      * @throws Throwable
+     *             for some failure scenarios.
      */
     @Test
     public void testSkipBig() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        assertEquals(3, b32stream.skip(1024));
-        // End of stream reached
-        assertEquals(-1, b32stream.read());
-        assertEquals(-1, b32stream.read());
-        b32stream.close();
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            assertEquals(3, b32stream.skip(1024));
+            // End of stream reached
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+        }
+    }
+
+    /**
+     * Tests skipping as a noop
+     *
+     * @throws Throwable
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testSkipNone() throws Throwable {
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            final byte[] actualBytes = new byte[6];
+            assertEquals(0, b32stream.skip(0));
+            b32stream.read(actualBytes, 0, actualBytes.length);
+            assertArrayEquals(actualBytes, new byte[] { 102, 111, 111, 0, 0, 0 });
+            // End of stream reached
+            assertEquals(-1, b32stream.read());
+        }
     }
 
     /**
      * Tests skipping past the end of a stream.
      *
      * @throws Throwable
+     *             for some failure scenarios.
      */
     @Test
     public void testSkipPastEnd() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
-        assertEquals(3, b32stream.skip(10));
-        // End of stream reached
-        assertEquals(-1, b32stream.read());
-        assertEquals(-1, b32stream.read());
-        b32stream.close();
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
+            assertEquals(3, b32stream.skip(10));
+            // End of stream reached
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+        }
 }
 
     /**
      * Tests skipping to the end of a stream.
      *
      * @throws Throwable
+     *             for some failure scenarios.
      */
     @Test
     public void testSkipToEnd() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
-        assertEquals(3, b32stream.skip(3));
-        // End of stream reached
-        assertEquals(-1, b32stream.read());
-        assertEquals(-1, b32stream.read());
-        b32stream.close();
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            // due to CODEC-130, skip now skips correctly decoded characters rather than encoded
+            assertEquals(3, b32stream.skip(3));
+            // End of stream reached
+            assertEquals(-1, b32stream.read());
+            assertEquals(-1, b32stream.read());
+        }
     }
 
     /**
      * Tests if negative arguments to skip are handled correctly.
      *
      * @throws Throwable
+     *             for some failure scenarios.
      */
-    @Test(expected=IllegalArgumentException.class)
+    @Test
     public void testSkipWrongArgument() throws Throwable {
-        InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
-        Base32InputStream b32stream = new Base32InputStream(ins);
-        b32stream.skip(-10);
-        b32stream.close();
+        final InputStream ins = new ByteArrayInputStream(StringUtils.getBytesIso8859_1(ENCODED_FOO));
+        try (final Base32InputStream b32stream = new Base32InputStream(ins)) {
+            assertThrows(IllegalArgumentException.class, () -> b32stream.skip(-10));
+        }
+    }
+
+    /**
+     * Test strict decoding.
+     *
+     * @throws Exception
+     *             for some failure scenarios.
+     */
+    @Test
+    public void testStrictDecoding() throws Exception {
+        for (final String s : Base32Test.BASE32_IMPOSSIBLE_CASES) {
+            final byte[] encoded = StringUtils.getBytesUtf8(s);
+            final Base32InputStream in = new Base32InputStream(new ByteArrayInputStream(encoded), false);
+            // Default is lenient decoding; it should not throw
+            assertFalse(in.isStrictDecoding());
+            BaseNTestData.streamToBytes(in);
+
+            // Strict decoding should throw
+            final Base32InputStream in2 = new Base32InputStream(new ByteArrayInputStream(encoded), false, 0, null, CodecPolicy.STRICT);
+            assertTrue(in2.isStrictDecoding());
+            assertThrows(IllegalArgumentException.class, () -> BaseNTestData.streamToBytes(in2));
+        }
     }
 }
