@@ -17,8 +17,9 @@
 
 package org.apache.commons.codec.digest;
 
-import static org.junit.Assert.assertNotNull;
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+
+import org.junit.jupiter.api.Test;
 
 public class Sha2CryptTest {
 
