@@ -17,28 +17,27 @@
 
 package org.apache.commons.codec.language;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import org.apache.commons.codec.StringEncoderAbstractTest;
-import org.junit.Test;
+import org.apache.commons.codec.AbstractStringEncoderTest;
+import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link DoubleMetaphone}.
  * <p>
  * The test data was extracted from Stephen Woodbridge's <a
- * href="http://swoodbridge.com/DoubleMetaPhone/surnames.txt">PHP test program</a>.
+ * href="https://swoodbridge.com/DoubleMetaPhone/surnames.txt">PHP test program</a>.
  *
- * @see <a href="http://swoodbridge.com/DoubleMetaPhone/surnames.txt">PHP test program</a>
- * @version $Id$
+ * @see <a href="https://swoodbridge.com/DoubleMetaPhone/surnames.txt">PHP test program</a>
  */
-public class DoubleMetaphone2Test extends StringEncoderAbstractTest<DoubleMetaphone> {
+public class DoubleMetaphone2Test extends AbstractStringEncoderTest<DoubleMetaphone> {
 
     private static final int ALTERNATE_INDEX = 2;
 
     private static final int PRIMARY_INDEX = 1;
 
     /** Test values and their expected primary & alternate Double Metaphone encodings */
-    private static final String[][] TEST_DATA = new String[][]{
+    private static final String[][] TEST_DATA = {
         {"ALLERTON", "ALRT", "ALRT"},
         {"Acton", "AKTN", "AKTN"},
         {"Adams", "ATMS", "ATMS"},
@@ -1264,7 +1263,7 @@ public class DoubleMetaphone2Test extends StringEncoderAbstractTest<DoubleMetaph
     private void checkDoubleMetaphone(final int typeIndex, final boolean alternate) {
         for (int i = 0; i < TEST_DATA.length; i++) {
             final String value = TEST_DATA[i][0];
-            assertEquals("Test [" + i + "]=" + value, TEST_DATA[i][typeIndex], this.getStringEncoder().doubleMetaphone(value, alternate));
+            assertEquals(TEST_DATA[i][typeIndex], this.getStringEncoder().doubleMetaphone(value, alternate), "Test [" + i + "]=" + value);
         }
     }
 
